@@ -34,6 +34,7 @@
 #include "dhcp4config.h"
 #include "dhcp6config.h"
 #include "activeconnection.h"
+#include "devicestatistics.h"
 
 namespace NetworkManager
 {
@@ -65,9 +66,8 @@ class NETWORKMANAGERQT_EXPORT Device : public QObject
     Q_PROPERTY(bool firmwareMissing READ firmwareMissing)
     Q_PROPERTY(bool autoconnect READ autoconnect WRITE setAutoconnect)
     Q_PROPERTY(DeviceStateReason stateReason READ stateReason)
-
-    //Q_PROPERTY(Solid::Control::IPv4Config ipV4Config READ ipV4Config WRITE setIpV4Config)
     Q_PROPERTY(State state READ state)
+    Q_PROPERTY(NetworkManager::DeviceStatistics::Ptr deviceStatistics READ deviceStatistics)
 
 public:
     typedef QSharedPointer<Device> Ptr;
@@ -144,26 +144,30 @@ public:
      * Device type
      */
     enum Type {
-        UnknownType = NM_DEVICE_TYPE_UNKNOWN, /**< Unknown device type */
-        Ethernet = NM_DEVICE_TYPE_ETHERNET, /**< Ieee8023 wired ethernet */
-        Wifi = NM_DEVICE_TYPE_WIFI, /**< the Ieee80211 family of wireless networks */
-        Unused1 = NM_DEVICE_TYPE_UNUSED1, /**< Currently unused */
-        Unused2 = NM_DEVICE_TYPE_UNUSED2, /**< Currently unused */
-        Bluetooth = NM_DEVICE_TYPE_BT, /**< network bluetooth device (usually a cell phone) */
-        OlpcMesh = NM_DEVICE_TYPE_OLPC_MESH, /**< OLPC Mesh networking device */
-        Wimax = NM_DEVICE_TYPE_WIMAX, /**< WiMax WWAN technology */
-        Modem = NM_DEVICE_TYPE_MODEM, /**< POTS, GSM, CDMA or LTE modems */
+        UnknownType = NM_DEVICE_TYPE_UNKNOWN,   /**< Unknown device type */
+        Ethernet = NM_DEVICE_TYPE_ETHERNET,     /**< Ieee8023 wired ethernet */
+        Wifi = NM_DEVICE_TYPE_WIFI,             /**< the Ieee80211 family of wireless networks */
+        Unused1 = NM_DEVICE_TYPE_UNUSED1,       /**< Currently unused */
+        Unused2 = NM_DEVICE_TYPE_UNUSED2,       /**< Currently unused */
+        Bluetooth = NM_DEVICE_TYPE_BT,          /**< network bluetooth device (usually a cell phone) */
+        OlpcMesh = NM_DEVICE_TYPE_OLPC_MESH,    /**< OLPC Mesh networking device */
+        Wimax = NM_DEVICE_TYPE_WIMAX,           /**< WiMax WWAN technology */
+        Modem = NM_DEVICE_TYPE_MODEM,           /**< POTS, GSM, CDMA or LTE modems */
         InfiniBand = NM_DEVICE_TYPE_INFINIBAND, /**< Infiniband network device */
-        Bond = NM_DEVICE_TYPE_BOND, /**< Bond virtual device */
-        Vlan = NM_DEVICE_TYPE_VLAN, /**< Vlan virtual device */
-        Adsl = NM_DEVICE_TYPE_ADSL, /**< ADSL modem device */
-        Bridge = NM_DEVICE_TYPE_BRIDGE, /**< Bridge virtual device */
-        Generic = NM_DEVICE_TYPE_GENERIC, /**< Generic device @since 0.9.9.0 */
-        Team = NM_DEVICE_TYPE_TEAM, /**< Team master device @since 0.9.9.0 */
-        Gre, /**< Gre virtual device @since 0.9.9.0 */
-        MacVlan, /**< MacVlan virtual device @since 0.9.9.0 */
-        Tun, /**< Tun virtual device @since 0.9.9.0 */
-        Veth, /**< Veth virtual device @since 0.9.9.0 */
+        Bond = NM_DEVICE_TYPE_BOND,             /**< Bond virtual device */
+        Vlan = NM_DEVICE_TYPE_VLAN,             /**< Vlan virtual device */
+        Adsl = NM_DEVICE_TYPE_ADSL,             /**< ADSL modem device */
+        Bridge = NM_DEVICE_TYPE_BRIDGE,         /**< Bridge virtual device */
+        Generic = NM_DEVICE_TYPE_GENERIC,       /**< Generic device @since 1.0.0 */
+        Team = NM_DEVICE_TYPE_TEAM,             /**< Team master device @since 1.0.0 */
+        Gre,                                    /**< Gre virtual device @since 1.2.0, @deprecated use IpTunnel instead*/
+        MacVlan,                                /**< MacVlan virtual device @since 1.2.0 */
+        Tun,                                    /**< Tun virtual device @since 1.2.0 */
+        Veth,                                   /**< Veth virtual device @since 1.2.0 */
+        IpTunnel,                               /**< IP Tunneling Device @since 1.2.0 */
+        VxLan,                                  /**< Vxlan Device @since 1.2.0 */
+        MacSec,                                 /**< MacSec Device @since 1.6.0 */
+        Dummy                                   /**< Dummy Device @since 1.8.0 */
     };
     Q_ENUM(Type)
     Q_DECLARE_FLAGS(Types, Type)
@@ -376,6 +380,12 @@ public:
      */
     void setAutoconnect(bool autoconnect);
 
+    /**
+     * Returns Device Statistics interface
+     * @note always returns empty pointer in runtime NM < 1.4.0
+     */
+    DeviceStatistics::Ptr deviceStatistics() const;
+
     /**
       * Retrieves a specialized interface to interact with the device corresponding
       * to a given device interface.
@@ -518,7 +528,7 @@ Q_SIGNALS:
      * Emitted when NmPluginMissing property has changed
      * @since 5.14.0
      * @see nmPluginMissing
-     * @note never emmited in runtime NM < 1.2.0
+     * @note never Emitted in runtime NM < 1.2.0
      */
     void nmPluginMissingChanged(bool nmPluginMissing);
 
@@ -526,7 +536,7 @@ Q_SIGNALS:
      * Emitted when metered property has changed
      * @since 5.14.0
      * @see metered
-     * @note never emmited in runtime NM < 1.0.6
+     * @note never Emitted in runtime NM < 1.0.6
      */
     void meteredChanged(MeteredStatus metered);
 
